package bodybuilder.viewer.handler;

import java.io.PrintWriter;

/**
 * 標準出力ハンドラ。
 */
public class StandardOutputHandler extends AbstractOutputHandler {

    /**
     * コンストラクタ。
     */
    public StandardOutputHandler() {
        // 出力先を標準出力にする。
        printWriter = new PrintWriter(System.out, true);
        tab = "  ";
    }

}